IdRemap class final

Where an element went when the mesh was compacted, or EditMesh.none where it was dropped.

Constructors

IdRemap({required Int32List vertices, required Int32List faces})
const

Properties

faces → Int32List
Old face number to new.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertices → Int32List
Old vertex number to new, indexed by the old one.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited